#!/bin/bash
#
# packager          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# package           : stjerm
# homepage          : http://code.google.com/p/stjerm-terminal/
# source location   : http://stjerm-terminal-emulator.googlecode.com/files/stjerm-0.14.tar.bz2
# dependency        : 

softname='stjerm'
softversion='0.14'
packageversion='66.1'

arch='i686'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.gz"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://stjerm-terminal.googlecode.com/files/$softname-$softversion.tar.gz

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
      |-----handy-ruler------------------------------------------------------|
stjerm: stjerm - A quake-like terminal emulator
stjerm:
stjerm: It's window is shown with a key shortcut. Stjerm is very
stjerm: minimalistic and works well with Compiz window manager.
stjerm:
stjerm:
stjerm:
stjerm:
stjerm:
stjerm:
stjerm:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src	

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

./autogen.sh

./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--localedir="/usr/share/locale" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make $numjobs DESTDIR=$dest
make install DESTDIR=$dest

# make .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Name=Stjerm
Comment=Use the command line in a Quake like terminal
Exec=stjerm -o 80 -k F12
Icon=utilities-terminal
Categories=Application;Utility;TerminalEmulator;
Terminal=false
Type=Application
Encoding=UTF-8
EOF

# add 'default' files
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS README \
      $dest/usr/doc/$softname-$softversion
	
# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# Compress Man Pages
( cd $dest/$prefix/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# dep file
cd $buildir
echo -e "atk,cairo,expat,fontconfig,freetype,glib2,\
gtk+2,libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,\
libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,libpng,\
libxcb,ncurses,pango,pixman,vte,xcb-util,zlib" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/xap/stjerm-terminal/source/build-stjerm.sh > $package.src
echo $source >> $package.src

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
